@@ -1,5 +1,6 @@
 """Module for testing Coding DNA Silent Mutation Classifier."""
 import unittest
+
 from variation.classifiers import CodingDNASilentMutationClassifier
 from .classifier_base import ClassifierBase
 
@@ -13,4 +14,4 @@ class TestCodingDNASilentMutationClassifier(ClassifierBase, unittest.TestCase):
 
     def fixture_name(self):
         """Return CodingDNASilentMutationClassifier fixture name."""
-        return 'coding_dna_silent_mutation'
+        return "coding_dna_silent_mutation"
