@@ -1,5 +1,6 @@
 """Module for testing Genomic DelIns Classifier."""
 import unittest
+
 from variation.classifiers import GenomicDelInsClassifier
 from .classifier_base import ClassifierBase
 
@@ -13,4 +14,4 @@ class TestGenomicDelInsClassifier(ClassifierBase, unittest.TestCase):
 
     def fixture_name(self):
         """Return GenomicDelInsClassifier fixture name."""
-        return 'genomic_delins'
+        return "genomic_delins"
