@@ -1,5 +1,6 @@
 """Module for testing Genomic Insertion Classifier."""
 import unittest
+
 from variation.classifiers import GenomicInsertionClassifier
 from .classifier_base import ClassifierBase
 
@@ -13,4 +14,4 @@ class TestGenomicInsertionClassifier(ClassifierBase, unittest.TestCase):
 
     def fixture_name(self):
         """Return GenomicInsertionClassifier fixture name."""
-        return 'genomic_insertion'
+        return "genomic_insertion"
