@@ -1,5 +1,6 @@
 """A module for testing Genomic Silent Mutation tokenization."""
 import unittest
+
 from variation.tokenizers import GenomicSilentMutation
 from .tokenizer_base import TokenizerBase
 
@@ -13,8 +14,8 @@ class TestGenomicSilentMutationTokenizer(TokenizerBase, unittest.TestCase):
 
     def token_type(self):
         """Return genomic silent mutation token type."""
-        return 'GenomicSilentMutation'
+        return "GenomicSilentMutation"
 
     def fixture_name(self):
         """Return the fixture name for coding  DNA silent mutation."""
-        return 'genomic_silent_mutation'
+        return "genomic_silent_mutation"
