@@ -1,5 +1,6 @@
 """A module for testing Genomic Uncertain Deletion tokenization."""
 import unittest
+
 from variation.tokenizers import GenomicUncertainDeletion
 from .tokenizer_base import TokenizerBase
 
@@ -13,8 +14,8 @@ class TestGenomicUncertainDeletionTokenizer(TokenizerBase, unittest.TestCase):
 
     def token_type(self):
         """Return genomic uncertain deletion token type."""
-        return 'GenomicUncertainDeletion'
+        return "GenomicUncertainDeletion"
 
     def fixture_name(self):
         """Return the fixture name for genomic uncertain deletion."""
-        return 'genomic_uncertain_deletion'
+        return "genomic_uncertain_deletion"
