@@ -1,5 +1,6 @@
 """Module for testing Genomic Deletion Validator."""
 import unittest
+
 from variation.validators import GenomicDeletion
 from variation.classifiers import GenomicDeletionClassifier
 from .validator_base import ValidatorBase
@@ -18,4 +19,4 @@ class TestGenomicDeletionValidator(ValidatorBase, unittest.TestCase):
 
     def fixture_name(self):
         """Return the fixture name for genomic deletion."""
-        return 'genomic_deletion'
+        return "genomic_deletion"
