@@ -1,5 +1,6 @@
 """Module for testing Polypeptide Truncation Validator."""
 import unittest
+
 from variation.validators import PolypeptideTruncation
 from variation.classifiers import PolypeptideTruncationClassifier
 from .validator_base import ValidatorBase
@@ -18,4 +19,4 @@ class TestPolypeptideTruncationValidator(ValidatorBase, unittest.TestCase):
 
     def fixture_name(self):
         """Return the fixture name for Polypeptide Truncation."""
-        return 'polypeptide_truncation'
+        return "polypeptide_truncation"
