@@ -1,15 +1,16 @@
 """A module for testing validator classes."""
 import yaml
-from tests import PROJECT_ROOT
-from variation.vrs import VRS
-from variation.tokenizers import Tokenize, GeneSymbol
-from variation.tokenizers.caches import AminoAcidCache
-from variation.data_sources import TranscriptMappings, SeqRepoAccess, \
-    MANETranscriptMappings, UTA
-from variation.mane_transcript import MANETranscript
 from ga4gh.vrs.dataproxy import SeqRepoDataProxy
 from ga4gh.vrs.extras.translator import Translator
 from gene.query import QueryHandler as GeneQueryHandler
+from cool_seq_tool.data_sources import TranscriptMappings, SeqRepoAccess, \
+    MANETranscriptMappings, UTADatabase, MANETranscript
+
+from tests import PROJECT_ROOT
+from variation.schemas.app_schemas import Endpoint
+from variation.vrs_representation import VRSRepresentation
+from variation.tokenizers import Tokenize, GeneSymbol
+from variation.tokenizers.caches import AminoAcidCache
 
 
 class ValidatorBase:
@@ -18,7 +19,7 @@ class ValidatorBase:
     @classmethod
     def setUpClass(cls):
         """Set up the test cases."""
-        with open(f'{PROJECT_ROOT}/tests/fixtures/validators.yml') as stream:
+        with open(f"{PROJECT_ROOT}/tests/fixtures/validators.yml") as stream:
             cls.all_fixtures = yaml.safe_load(stream)
         amino_acid_cache = AminoAcidCache()
         gene_normalizer = GeneQueryHandler()
@@ -27,16 +28,17 @@ class ValidatorBase:
 
         seqrepo_access = SeqRepoAccess()
         transcript_mappings = TranscriptMappings()
-        uta = UTA()
-        dp = SeqRepoDataProxy(seqrepo_access.seq_repo_client)
+        uta = UTADatabase()
+        dp = SeqRepoDataProxy(seqrepo_access.seqrepo_client)
         tlr = Translator(data_proxy=dp)
         mane_transcript = MANETranscript(
-            seqrepo_access, transcript_mappings, MANETranscriptMappings(), uta)
-        vrs = VRS(dp, seqrepo_access)
+            seqrepo_access, transcript_mappings, MANETranscriptMappings(), uta,
+            gene_normalizer)
+        vrs = VRSRepresentation(dp, seqrepo_access)
 
         cls.aa_params = [
             seqrepo_access, transcript_mappings, gene_symbol,
-            mane_transcript, uta, dp, tlr, gene_normalizer,
+            mane_transcript, uta, tlr, gene_normalizer,
             vrs, amino_acid_cache
         ]
         cls.params = cls.aa_params[:-1]
@@ -57,20 +59,20 @@ class ValidatorBase:
         """Initialize fixtures, classifier + validator"""
         self.fixtures = self.all_fixtures.get(
             self.fixture_name(),
-            {'should_match': [], 'should_not_match': []}
+            {"should_match": [], "should_not_match": []}
         )
         self.classifier = self.classifier_instance()
         self.validator = self.validator_instance()
 
-    def test_matches(self):
+    async def test_matches(self):
         """Test that validator matches correctly."""
         self.set_up()
-        for x in self.fixtures['should_match']:
-            tokens = self.tokenizer.perform(x['query'], [])
+        for x in self.fixtures["should_match"]:
+            tokens = self.tokenizer.perform(x["query"], [])
             classification = self.classifier.match(tokens)
-            validation_results = self.validator.validate(
-                classification, normalize_endpoint=True,
-                hgvs_dup_del_mode="default"
+            validation_results = await self.validator.validate(
+                classification, hgvs_dup_del_mode="default",
+                endpoint_name=Endpoint.TO_VRS
             )
             is_valid = False
             for vr in validation_results:
@@ -80,14 +82,14 @@ class ValidatorBase:
             self.assertTrue(is_valid, msg=x)
             self.assertIsNotNone(validation_results, msg=x)
 
-    def test_not_matches(self):
+    async def test_not_matches(self):
         """Test that validator matches correctly."""
         self.set_up()
-        for x in self.fixtures['should_not_match']:
-            tokens = self.tokenizer.perform(x['query'], [])
+        for x in self.fixtures["should_not_match"]:
+            tokens = self.tokenizer.perform(x["query"], [])
             classification = self.classifier.match(tokens)
-            validation_results = self.validator.validate(
-                classification, normalize_endpoint=True
+            validation_results = await self.validator.validate(
+                classification, endpoint_name=Endpoint.TO_VRS
             )
             is_valid = False
             for vr in validation_results:
