@@ -1,7 +1,8 @@
 """A module for the Genomic Deletion Classifier."""
 from typing import List
-from .set_based_classifier import SetBasedClassifier
+
 from variation.schemas.classification_response_schema import ClassificationType
+from .set_based_classifier import SetBasedClassifier
 
 
 class GenomicDeletionClassifier(SetBasedClassifier):
@@ -14,11 +15,11 @@ class GenomicDeletionClassifier(SetBasedClassifier):
     def exact_match_candidates(self) -> List[List[str]]:
         """Return the exact match token type candidates."""
         return [
-            ['Chromosome', 'GenomicDeletion'],
-            ['GeneSymbol', 'AminoAcidSubstitution', 'GenomicDeletion'],
-            ['GenomicDeletion', 'GeneSymbol'],
-            ['GeneSymbol', 'GenomicDeletion'],
-            ['HGVS', 'GenomicDeletion'],
-            ['ReferenceSequence', 'GenomicDeletion'],
-            ['LocusReferenceGenomic', 'GenomicDeletion']
+            ["Chromosome", "GenomicDeletion"],
+            ["GeneSymbol", "ProteinSubstitution", "GenomicDeletion"],
+            ["GenomicDeletion", "GeneSymbol"],
+            ["GeneSymbol", "GenomicDeletion"],
+            ["HGVS", "GenomicDeletion"],
+            ["ReferenceSequence", "GenomicDeletion"],
+            ["LocusReferenceGenomic", "GenomicDeletion"]
         ]
