@@ -1,7 +1,8 @@
 """A module for the Genomic DelIns Classifier."""
 from typing import List
-from .set_based_classifier import SetBasedClassifier
+
 from variation.schemas.classification_response_schema import ClassificationType
+from .set_based_classifier import SetBasedClassifier
 
 
 class GenomicDelInsClassifier(SetBasedClassifier):
@@ -14,10 +15,10 @@ class GenomicDelInsClassifier(SetBasedClassifier):
     def exact_match_candidates(self) -> List[List[str]]:
         """Return the exact match token type candidates."""
         return [
-            ['Chromosome', 'GenomicDelIns'],
-            ['GeneSymbol', 'AminoAcidSubstitution', 'GenomicDelIns'],
-            ['GenomicDelIns', 'GeneSymbol'],
-            ['GeneSymbol', 'GenomicDelIns'],
-            ['HGVS', 'GenomicDelIns'],
-            ['ReferenceSequence', 'GenomicDelIns']
+            ["Chromosome", "GenomicDelIns"],
+            ["GeneSymbol", "ProteinSubstitution", "GenomicDelIns"],
+            ["GenomicDelIns", "GeneSymbol"],
+            ["GeneSymbol", "GenomicDelIns"],
+            ["HGVS", "GenomicDelIns"],
+            ["ReferenceSequence", "GenomicDelIns"]
         ]
