@@ -1,7 +1,8 @@
 """A module for the Genomic Insertion Classifier."""
 from typing import List
-from .set_based_classifier import SetBasedClassifier
+
 from variation.schemas.classification_response_schema import ClassificationType
+from .set_based_classifier import SetBasedClassifier
 
 
 class GenomicInsertionClassifier(SetBasedClassifier):
@@ -14,11 +15,11 @@ class GenomicInsertionClassifier(SetBasedClassifier):
     def exact_match_candidates(self) -> List[List[str]]:
         """Return the exact match token type candidates."""
         return [
-            ['Chromosome', 'GenomicInsertion'],
-            ['GeneSymbol', 'AminoAcidSubstitution', 'GenomicInsertion'],
-            ['GenomicInsertion', 'GeneSymbol'],
-            ['GeneSymbol', 'GenomicInsertion'],
-            ['HGVS', 'GenomicInsertion'],
-            ['ReferenceSequence', 'GenomicInsertion'],
-            ['LocusReferenceGenomic', 'GenomicInsertion']
+            ["Chromosome", "GenomicInsertion"],
+            ["GeneSymbol", "ProteinSubstitution", "GenomicInsertion"],
+            ["GenomicInsertion", "GeneSymbol"],
+            ["GeneSymbol", "GenomicInsertion"],
+            ["HGVS", "GenomicInsertion"],
+            ["ReferenceSequence", "GenomicInsertion"],
+            ["LocusReferenceGenomic", "GenomicInsertion"]
         ]
