@@ -1,7 +1,8 @@
 """A module for the Genomic Uncertain Deletion Classifier."""
 from typing import List
-from .set_based_classifier import SetBasedClassifier
+
 from variation.schemas.classification_response_schema import ClassificationType
+from .set_based_classifier import SetBasedClassifier
 
 
 class GenomicUncertainDeletionClassifier(SetBasedClassifier):
@@ -14,10 +15,10 @@ class GenomicUncertainDeletionClassifier(SetBasedClassifier):
     def exact_match_candidates(self) -> List[List[str]]:
         """Return the exact match token type candidates."""
         return [
-            ['Chromosome', 'GenomicUncertainDeletion'],
-            ['GeneSymbol', 'GenomicUncertainDeletion'],
-            ['GenomicUncertainDeletion', 'GeneSymbol'],
-            ['HGVS', 'GenomicUncertainDeletion'],
-            ['ReferenceSequence', 'GenomicUncertainDeletion'],
-            ['LocusReferenceGenomic', 'GenomicUncertainDeletion']
+            ["Chromosome", "GenomicUncertainDeletion"],
+            ["GeneSymbol", "GenomicUncertainDeletion"],
+            ["GenomicUncertainDeletion", "GeneSymbol"],
+            ["HGVS", "GenomicUncertainDeletion"],
+            ["ReferenceSequence", "GenomicUncertainDeletion"],
+            ["LocusReferenceGenomic", "GenomicUncertainDeletion"]
         ]
