@@ -1,9 +1,11 @@
-"""Module for toVRS endpoint response schema."""
-from pydantic import BaseModel
+"""Module for to_vrs endpoint response schema."""
 from typing import List, Dict, Type, Any, Optional, Union
+
+from pydantic import BaseModel
 from pydantic.types import StrictStr
 from ga4gh.vrsatile.pydantic.vrs_models import Allele, Text, Haplotype, \
-    CopyNumber, VariationSet
+    AbsoluteCopyNumber, VariationSet
+
 from variation.schemas.normalize_response_schema import ServiceMeta
 
 
@@ -13,7 +15,7 @@ class ToVRSService(BaseModel):
     search_term: StrictStr
     warnings: Optional[List[StrictStr]]
     variations: Optional[Union[List[Allele], List[Text], List[Haplotype],
-                               List[CopyNumber], List[VariationSet]]] = None
+                               List[AbsoluteCopyNumber], List[VariationSet]]] = []
     service_meta_: ServiceMeta
 
     class Config:
@@ -125,30 +127,6 @@ class ToVRSService(BaseModel):
                             "type": "LiteralSequenceExpression",
                             "sequence": "E"
                         }
-                    },
-                    {
-                        "_id": "ga4gh:VA.8JkgnqIgYqufNl-OV_hpRG_aWF9UFQCE",
-                        "type": "Allele",
-                        "location": {
-                            "_id": "ga4gh:VSL.AqrQ-EkAvTrXOFn70_8i3dXF5shBBZ5i",  # noqa: E501
-                            "type": "SequenceLocation",
-                            "sequence_id": "ga4gh:SQ.WaAJ_cXXn9YpMNfhcq9lnzIvaB9ALawo",  # noqa: E501
-                            "interval": {
-                                "type": "SequenceInterval",
-                                "start": {
-                                    "type": "Number",
-                                    "value": 639
-                                },
-                                "end": {
-                                    "type": "Number",
-                                    "value": 640
-                                }
-                            }
-                        },
-                        "state": {
-                            "type": "LiteralSequenceExpression",
-                            "sequence": "E"
-                        }
                     }
                 ],
                 "service_meta_": {
