@@ -1,4 +1,6 @@
 """A module for Genomic DelIns Tokenization."""
+from typing import Dict, Optional
+
 from variation.schemas.token_response_schema import GenomicDelInsToken
 from variation.tokenizers.delins_base import DelInsBase
 
@@ -8,7 +10,7 @@ class GenomicDelIns(DelInsBase):
     genomic reference sequence.
     """
 
-    def return_token(self, params):
+    def return_token(self, params: Dict) -> Optional[GenomicDelInsToken]:
         """Return genomic delins token."""
-        if self.parts['reference_sequence'] == 'g':
+        if self.parts["coordinate_type"] == "g":
             return GenomicDelInsToken(**params)
