@@ -1,4 +1,6 @@
 """A module for Genomic Substitution Tokenization."""
+from typing import Dict, Optional
+
 from variation.schemas.token_response_schema import GenomicSubstitutionToken
 from .single_nucleotide_variation_base import SingleNucleotideVariationBase
 
@@ -8,9 +10,9 @@ class GenomicSubstitution(SingleNucleotideVariationBase):
     reference sequence.
     """
 
-    def return_token(self, params):
+    def return_token(self, params: Dict) -> Optional[GenomicSubstitutionToken]:
         """Return Genomic Substitution token."""
-        if self.sub['reference_sequence'] == 'g' and \
-                self.sub['ref_nucleotide'] is not None and \
-                self.sub['new_nucleotide'] != '=':
+        if self.sub["coordinate_type"] == "g" and \
+                self.sub["ref_nucleotide"] is not None and \
+                self.sub["new_nucleotide"] != "=":
             return GenomicSubstitutionToken(**params)
