@@ -1,7 +1,7 @@
 """Module for Coding DNA Silent Mutation Translation."""
 from variation.translators.translator import Translator
 from variation.schemas.classification_response_schema import ClassificationType
-from variation.schemas.token_response_schema import CodingDNASilentMutationToken
+from variation.schemas.token_response_schema import CodingDNASilentMutationToken, Token
 
 
 class CodingDNASilentMutation(Translator):
@@ -11,7 +11,7 @@ class CodingDNASilentMutation(Translator):
         """Return if classification type is Coding DNA Silent Mutation."""
         return type == ClassificationType.CODING_DNA_SILENT_MUTATION
 
-    def is_token_instance(self, token):
+    def is_token_instance(self, token: Token) -> bool:
         """Return if the token is an Coding DNA Silent Mutation token
         instance.
         """
