@@ -1,7 +1,7 @@
 """Module for Genomic Deletion Translation."""
 from variation.translators.translator import Translator
 from variation.schemas.classification_response_schema import ClassificationType
-from variation.schemas.token_response_schema import GenomicDeletionToken
+from variation.schemas.token_response_schema import GenomicDeletionToken, Token
 
 
 class GenomicDeletion(Translator):
@@ -11,6 +11,6 @@ class GenomicDeletion(Translator):
         """Return if classification type is Genomic Deletion."""
         return type == ClassificationType.GENOMIC_DELETION
 
-    def is_token_instance(self, token):
+    def is_token_instance(self, token: Token) -> bool:
         """Return if the token is an Genomic Deletion token instance."""
         return isinstance(token, GenomicDeletionToken)
