@@ -1,7 +1,7 @@
 """Module for Genomic Insertion Translation."""
 from variation.translators.translator import Translator
 from variation.schemas.classification_response_schema import ClassificationType
-from variation.schemas.token_response_schema import GenomicInsertionToken
+from variation.schemas.token_response_schema import GenomicInsertionToken, Token
 
 
 class GenomicInsertion(Translator):
@@ -11,6 +11,6 @@ class GenomicInsertion(Translator):
         """Return if classification type is Genomic Insertion."""
         return type == ClassificationType.GENOMIC_INSERTION
 
-    def is_token_instance(self, token):
+    def is_token_instance(self, token: Token) -> bool:
         """Return if the token is an Genomic Insertion token instance."""
         return isinstance(token, GenomicInsertionToken)
