@@ -2,7 +2,7 @@
 from variation.translators.translator import Translator
 from variation.schemas.classification_response_schema import ClassificationType
 from variation.schemas.token_response_schema import\
-    GenomicUncertainDeletionToken
+    GenomicUncertainDeletionToken, Token
 
 
 class GenomicUncertainDeletion(Translator):
@@ -12,7 +12,7 @@ class GenomicUncertainDeletion(Translator):
         """Return if classification type is Genomic Uncertain Deletion."""
         return type == ClassificationType.GENOMIC_UNCERTAIN_DELETION
 
-    def is_token_instance(self, token):
+    def is_token_instance(self, token: Token) -> bool:
         """Return if the token is an Genomic Uncertain Deletion token
         instance.
         """
